from django.conf import settings
from typing import Sequence
from django_tsp.defaults import default_names


class Settings:
    """
    Shadow Django's settings with a little logic
    """
    @property
    def NAME_LIST(self) -> Sequence[str]:
        return getattr(settings, "NAME_LIST", default_names)

    @property
    def COMPANY_NAME(self) -> str:
        return getattr(settings, "CORS_PREFLIGHT_MAX_AGE", "CoolBlue")

conf = Settings()


from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _
from django.core.checks import register
from django.core.checks import Tags

from django_tsp.checks import check_settings


class TspConfig(AppConfig):
    name = 'tsp_wrapper'
    label = 'tsp_wrapper'
    verbose_name = _('Travel Salesman Problem Wrapper')

    def ready(self) -> None:
        register(Tags.security)(check_settings)


from django_tsp.conf import conf
from django.conf import settings


def say_hi():
    print("HELLLLLLLLLLLLLLLLLLLOOOOOOOOOOOOOOOOO")

def greeting(name:str) -> None:
    print(name)

def print_company():
    print(conf.COMPANY_NAME)

def print_list():
    print(conf.NAME_LIST)

def say_ok():
    print(settings.get("RQ_NAME"))


from collections.abc import Sequence
from typing import Any

from django.conf import settings
from django.core.checks import CheckMessage
from django.core.checks import Error

from django_tsp.conf import conf


def check_settings(**kwargs: Any) -> list[CheckMessage]:
    errors: list[CheckMessage] = []

    if not is_sequence(conf.NAME_LIST, str):
        errors.append(
            Error(
                "NAME_LIST should be a sequence of strings.",
                id="django_tsp.E001",
            )
        )

    if not isinstance(conf.COMPANY_NAME, str):
        errors.append(
            Error("COMPANY_NAME should be a string.", id="django_tsp.E009")
        )

    if hasattr(settings, "REQ_NAME"):
        errors.append(
            Error(
                (
                    "The REQ_NAME setting has been removed"
                    + " - see django_tsp' CHANGELOG."
                ),
                id="django_tsp.E013",
            )
        )

    return errors

def is_sequence(thing: Any, type_or_types: type[Any] | tuple[type[Any], ...]) -> bool:
    return isinstance(thing, Sequence) and all(
        isinstance(x, type_or_types) for x in thing
    )